Page

Struct Page 

pub struct Page {
    pub contents: String,
    pub filename: String,
}

Fields

contents: Stringfilename: String

Implementations

Source

impl Page

pub fn new_from_template<T: Serialize>( filename: &str, templates: &Templates<'_>, template_name: &str, context: &T, ) -> Result<Self>

Creates a new page by rendering a template, using the provided template name and template context, and using the filename parameter as the output file name.

pub fn new_from_markdown( path: &str, templates: &Templates<'_>, config: &Config, fail_fast: bool, ) -> Result<Self>

Creates a new page by rendering a Markdown file into the โ€œmarkdown pageโ€ template. Automatically determines the output path based on the path to the input Markdown file, diffing it with the basepath of the project.

pub fn new_from_both<T: Serialize>( path: &str, filename: &str, templates: &Templates<'_>, template_name: &str, context: T, config: &Config, ) -> Result<Self>

Combines both above functions by rendering a Markdown file into an arbitrary template. The markdown content itself will be available under the โ€œmarkdown_contentโ€ key in the template itself.

If the provided path doesnโ€™t exist, it will keep rendering the other content, and output a warning to the console.

pub fn filename(source: &str) -> String